/*****************************************************************************/
/* Controller:  */
/*****************************************************************************/
angular.module('maat.controllers', [])

.controller('AppCtrl', function($scope, $rootScope, $timeout, $http,
  requestService, $location, $state, $ionicHistory,
  $ionicScrollDelegate) {

  /*****************************************************************************/
  /* Layout Methods:  */
  /*****************************************************************************/
  var navIcons = document.getElementsByClassName('ion-navicon');
  for (var i = 0; i < navIcons.length; i++) {
    navIcons.addEventListener('click', function() {
      this.classList.toggle('active');
    });
  }

  $scope.hideNavBar = function() {
    document.getElementsByTagName('ion-nav-bar')[0].style.display = 'none';
  };

  $scope.showNavBar = function() {
    document.getElementsByTagName('ion-nav-bar')[0].style.display = 'block';
  };

  $scope.noHeader = function() {
    var content = document.getElementsByTagName('ion-content');
    for (var i = 0; i < content.length; i++) {
      if (content[i].classList.contains('has-header')) {
        content[i].classList.toggle('has-header');
      }
    }
  };

  $scope.hasHeader = function() {
    var content = document.getElementsByTagName('ion-content');
    for (var i = 0; i < content.length; i++) {
      if (!content[i].classList.contains('has-header')) {
        content[i].classList.toggle('has-header');
      }
    }
  };

  $scope.disableSetMonth = function() {
    document.getElementsByClassName('set-month')[0].disabled = true;
    document.getElementsByClassName('set-month')[1].disabled = true;
  };

  $scope.enableSetMonth = function() {
    document.getElementsByClassName('set-month')[0].disabled = false;
    document.getElementsByClassName('set-month')[1].disabled = false;
  };

  $scope.hideHeader = function() {
    $scope.hideNavBar();
    $scope.noHeader();
  };

  $scope.showHeader = function() {
    $scope.showNavBar();
    $scope.hasHeader();
  };

  /*****************************************************************************/
  /* End Layout Methods:  */
  /*****************************************************************************/

  $scope.showSettings = function() {
    if ($state.includes('app.enterprises')) {return true;}
    return false;
  };

  $scope.goSettings = function() {
    $state.go('app.newpassword');
  };

  $scope.enterpriseName = '';
  $scope.hideLoading = function(message) {
    if (!message.match(/\./gi)) {
      return true;
    }
    return false;
  }

  // search & date interval
  $scope.showSearchBar = true;
  $scope.isSearch = false;
  $scope.toggleSearch = function() {
    $scope.search = {};
    $scope.search.text = '';
    $scope.message = 'Nada encontrado';
    $scope.isSearch = $scope.isSearch === true ? false : true;
    $timeout(function() {
      $ionicScrollDelegate.scrollTop();
    }, 100);
  };
  $scope.cleanSearch = function() {
    $scope.isSearch = false;
    $scope.search = {};
    $scope.search.text = '';
  };

  $scope.loadData = function(dataSource, data) {
    $scope.message = 'Carregando...';
    $scope[dataSource] = [];
    requestService[dataSource](data)
    .success(function(data) {
      console.log('data retrieve: ', data);
      $timeout(function() {
        $scope[dataSource] = data[dataSource];

        if (!data || !$scope[dataSource] || !$scope[dataSource].length) {
          $scope.filiais = [];
          $scope.message = 'Sem informações';
          return false;
        }

        $scope.nome = {};
        $scope.nome.empresa = data.nomeEmpresa ? data.nomeEmpresa : '';
      }, 500);
    })
    .error(function(data, status) {
      if (_.contains(_.range(500,600), status)) {
        $scope.isOutService = true;
        $scope.message = 'Erro de comunicação com o servidor. Reconectando...';
        $timeout(function() {
          $scope.loadData(dataSource, data);
        }, 1000);
      }

      if(window.Connection &&
        navigator.connection.type === window.Connection.NONE) {
        $scope.isOutService = true;
        $scope.message = 'Sem conexão com a internet. Reconectando...';
        $timeout(function() {
          $scope.loadData(dataSource, data);
        }, 1000);
      }

      if (!window.localStorage['token']) {
        console.log("lost token", window.localStorage['token']);
        $ionicHistory.nextViewOptions({
          disableBack: true
        });
        $state.go('app.login');
        $scope.error = 'Faça o login';
        $ionicHistory.clearHistory();
        $ionicHistory.clearCache();
      }
    });
  };
})

.controller('LoginCtrl', function($scope, $timeout,
  credentialsService, $http, $state, $ionicHistory, fix, config) {
  $timeout(function() {
    $scope.$parent.hideHeader();
    fix.numberPlaceholder();
    var token = window.localStorage['token'];
    if (token) {
      $state.go('app.enterprises');
    }
  }, 0);

  $scope.appversion = config.APP_VERSION;
  $scope.loginData = {};
  $scope.button = 'Entrar';
  $scope.$parent.error = '';
  $scope.login = function() {
    $scope.button = 'Carregando...';
    credentialsService.login($scope.loginData)
    .success(function(data) {
      $scope.error = '';
      $ionicHistory.clearCache();
      $ionicHistory.clearHistory();
      $http.defaults.headers.common.token = data.token;
      window.localStorage['token'] = data.token;
      $state.go('app.enterprises');
    })
    .error(function(data, status) {
      console.log(data, status);
      var message = 'CPF e/ou senha incorretos';

      if(window.Connection &&
        navigator.connection.type === window.Connection.NONE) {
        message = 'Sem conexão com a internet';
      }

      if (_.contains(_.range(500,600), status)) {
        message = 'Erro de comunicação com o servidor';
      }

      $scope.error = message;
      $scope.button = 'Entrar';
      return;
    });
  };
  ionic.material.ink.displayEffect();
})

.controller('NewPasswordCtrl', function($scope, $timeout,
  $state, $http, $ionicHistory, credentialsService, config) {
  $timeout(function() {
    $scope.$parent.showHeader();
    $scope.$parent.showSearchBar = false;
  }, 0);

  $scope.appversion = config.APP_VERSION;
  $scope.logoutButton = 'Sair';
  $scope.logout = function() {
    $scope.logoutButton = 'Carregando...';
    credentialsService.logout();
    $http.defaults.headers.common.token = '';
    window.localStorage['token'] = '';
    $ionicHistory.nextViewOptions({
      disableBack: true
    });
    $state.go('app.login');
    $ionicHistory.clearHistory();
    $ionicHistory.clearCache();
  };

  $scope.$parent.error = '';
  $scope.changePasswordButton = 'Alterar';
  $scope.passwordData = {};
  $scope.changePassword = function() {
    $scope.changePasswordButton = 'Carregando...';
    if ($scope.passwordData.newpassword !== $scope.passwordData.renewpassword) {
      $scope.changePasswordButton = 'Alterar';
      $scope.$parent.error = 'Novas senhas diferentes';
      return false;
    }
    if ($scope.passwordData.renewpassword.length < 6) {
      $scope.changePasswordButton = 'Alterar';
      $scope.$parent.error = 'Senha deve conter 6 ou mais dígitos';
      return false;
    }
    credentialsService.changePassword($scope.passwordData)
    .success(function() {
      $scope.$parent.error = 'Senha alterada com sucesso';
      $scope.changePasswordButton = 'Alterar';
    })
    .error(function(data, status) {
      var message = 'Senha incorreta';
      if(window.Connection &&
        navigator.connection.type === window.Connection.NONE) {
        message = 'Sem conexão com a internet';
      }

      if (_.contains(_.range(500,600), status)) {
        message = 'Erro de comunicação com o servidor';
      }

      $scope.$parent.error = message;
      $scope.changePasswordButton = 'Alterar';
    });
  };
  ionic.material.ink.displayEffect();
})

.controller('EnterprisesCtrl', function($http, $scope, $timeout) {
  $timeout(function() {
    $scope.$parent.showHeader();
    $scope.$parent.showSearchBar = true;
    $scope.cleanSearch();
    $scope.$parent.loadData('empresas');
  }, 0);

  $scope.getEnterpriseName = function(enterpriseName) {
    $scope.$parent.enterpriseName = enterpriseName;
  };

  // Activate ink for controller
  ionic.material.ink.displayEffect();
})

.controller('SubsidiariesCtrl', function($scope, $timeout,
  calendar, $stateParams) {
  $timeout(function() {
    $scope.$parent.showHeader();
    $scope.cleanSearch();
    $scope.picker = calendar.build($scope, $stateParams);
    var today = moment().add(1, 'day').format('YYYY-MM-DD');
    $scope.picker.setDate(today);
    calendar.setPeriodoData($scope, $stateParams);
    $scope.isActionable = true;
    console.log('I was called');
  }, 0);

  $scope.previousMonth = function() {
    console.log("previousMonth", $scope.isActionable);
    if ($scope.isActionable) {
      $scope.$parent.disableSetMonth();
      calendar.setPrevMonthDay($scope);
      calendar.setPeriodoData($scope, $stateParams);
      $scope.isActionable = false;
    }
  };

  $scope.nextMonth = function() {
    console.log("nextMonth", $scope.isActionable);
    if ($scope.isActionable) {
      $scope.$parent.disableSetMonth();
      calendar.setNextMonthDay($scope);
      calendar.setPeriodoData($scope, $stateParams);
      $scope.isActionable = false;
    }
  };

  // Activate ink for controller
  ionic.material.ink.displayEffect();
});
