/*****************************************************************************/
/* Directives:  */
/*****************************************************************************/

angular.module('maat.directives', [])

.directive('maatInput', function() {
  return {
    restrict: 'E',
    replace: true,
    template:
    '<label class="item item-input item-maat-label item-floating-label">'+
    '<span class="input-label"></span>'+
    '<input type="text"/>'+
    '</label>',
    compile: function(element, attr) {
      var label = element.find('span'),
          input = element.find('input');
      label.html(attr.placeholder);
      angular.forEach({
        'name': attr.name,
        'type': attr.type,
        'placeholder': attr.placeholder,
        'ng-value': attr.ngValue,
        'ng-model': attr.ngModel,
        'required':attr.required,
        'ng-required':attr.ngRequired,
        'ng-minlength':attr.ngMinlength,
        'ng-maxlength':attr.ngMaxlength,
        'ng-pattern':attr.ngPattern,
        'ng-change':attr.ngChange,
        'ng-trim':attr.trim,
        'ng-blur':attr.ngBlur,
        'ng-focus':attr.ngFocus,
      }, function(value, name) {
        if (angular.isDefined(value)) {
          input.attr(name, value);
        }
      });
      var cleanUp = function(){
        ionic.off('$destroy', cleanUp, element[0]);
      };
      ionic.on('$destroy', cleanUp, element[0]);
    }
  };
})

.directive('maatCard', function() {
  return {
    restrict: 'E',
    replace: true,
    template:
    '<ion-item class="card-item">' +
      '<div class="card light-bg ink ink-stable">' +
        '<header style="background-color: #b5b5b5" class="text-center">' +
          '<h2 ng-if="card.nome">{{card.nome}}</h2>' +
          '<h2 class="sub-cards" ng-if="card.data">' +
            '{{card.data | formatDate}}' +
          '</h2>' +
        '</header>' +
        '<section class="item item-text-wrap">' +
          '<article>' +
            '<p class="text-right">{{card.nota | translateScore}}</p>' +
            '<p style="padding:5px">' +
              '<i class="icon ion-clock"></i>' +
              'Horas' +
            '</p>' +
            '<div>' +
              '<div class="card-bar shadow"></div>' +
              '<div class="card-bar expected">' +
                '<strong style="padding-left: 5px;">Agendadas</strong>' +
                '<span class="pull-right">{{card.horasEsperadas | formatTime}}</span>' +
              '</div>' +
            '</div>' +
            '<div>' +
              '<div class="card-bar shadow"></div>' +
              '<div class="card-bar current"' +
              'ng-style="{{card.horasObservadas | widthHourBar:this}}">' +
                '<strong style="padding-left: 5px;">Realizadas</strong>' +
                '<span class="pull-right">{{card.horasObservadas | formatTime}}</span>' +
              '</div>' +
            '</div>' +
            '<p style="padding:5px">' +
              '<i class="icon ion-ios-people"></i>' +
              'Promotores' +
            '</p>' +
            '<div>' +
              '<div class="card-bar shadow"></div>' +
              '<div class="card-bar expected">' +
                '<strong style="padding-left: 5px;">Esperados</strong>' +
                '<span class="pull-right">{{card.promotoresEsperados}}</span>' +
              '</div>' +
            '</div>' +
            '<div>' +
              '<div class="card-bar shadow"></div>' +
              '<div class="card-bar current"' +
              'ng-style="{{card.promotoresObservados' +
                ' | widthPromoterBar:this}}">' +
                '<strong style="padding-left: 5px;">Observados</strong>' +
                '<span class="pull-right">{{card.promotoresObservados}}</span>'+
              '</div>' +
            '</div>' +
          '</article>' +
        '</section>' +
      '</ion-item>',
    compile: function(element, attr) {
      var input = element.find('input');
      angular.forEach({
        'name': attr.name,
        'type': attr.type,
        'placeholder': attr.placeholder,
        'ng-value': attr.ngValue,
        'ng-model': attr.ngModel,
        'required':attr.required,
        'ng-required':attr.ngRequired,
        'ng-minlength':attr.ngMinlength,
        'ng-maxlength':attr.ngMaxlength,
        'ng-pattern':attr.ngPattern,
        'ng-change':attr.ngChange,
        'ng-trim':attr.trim,
        'ng-blur':attr.ngBlur,
        'ng-focus':attr.ngFocus,
        'ng-repeat': attr.ngRepeat,
      }, function(value, name) {
        if (angular.isDefined(value)) {
          input.attr(name, value);
        }
      });
      var cleanUp = function(){
        ionic.off('$destroy', cleanUp, element[0]);
      };
      ionic.on('$destroy', cleanUp, element[0]);
    }
  };
})

.directive('maatCardSimple', function() {
  return {
    restrict: 'E',
    replace: true,
    template:
    '<ion-item class="card-item">' +
      '<div class="card light-bg ink ink-stable">' +
        '<header class="text-center">' +
          '<h2 class="title-card">{{card.nome}}</h2>' +
        '</header>' +
      '</div>' +
    '</ion-item>',
    compile: function(element, attr) {
      var input = element.find('input');
      angular.forEach({
        'ng-repeat': attr.ngRepeat,
      }, function(value, name) {
        if (angular.isDefined(value)) {
          input.attr(name, value);
        }
      });
      var cleanUp = function(){
        ionic.off('$destroy', cleanUp, element[0]);
      };
      ionic.on('$destroy', cleanUp, element[0]);
    }
  };
})

.directive('maatSubHeaderSearch', function() {
  return {
    restrict: 'E',
    replace: true,
    template:
    '<ion-header-bar class="bar-subheader" style="z-index:4;">' +
      '<input type="text" placeholder="Pesquisa por nome ou código" class="search-box">' +
    '</ion-header-bar>',
    compile: function(element, attr) {
      var input = element.find('input');
      angular.forEach({
        'name': attr.name,
        'type': attr.type,
        'placeholder': attr.placeholder,
        'ng-value': attr.ngValue,
        'ng-model': attr.ngModel,
        'required':attr.required,
        'ng-required':attr.ngRequired,
        'ng-minlength':attr.ngMinlength,
        'ng-maxlength':attr.ngMaxlength,
        'ng-pattern':attr.ngPattern,
        'ng-change':attr.ngChange,
        'ng-trim':attr.trim,
        'ng-blur':attr.ngBlur,
        'ng-focus':attr.ngFocus,
      }, function(value, name) {
        if (angular.isDefined(value)) {
          input.attr(name, value);
        }
      });
      var cleanUp = function() {
        ionic.off('$destroy', cleanUp, element[0]);
      };
      ionic.on('$destroy', cleanUp, element[0]);
    }
  };
})

.directive('maatSubHeaderDate', function() {
  return {
    restrict: 'E',
    replace: true,
    template:
    '<ion-header-bar class="bar-subheader"' +
    'style="background-color: #103C75;">' +
      '<h3 style="color:#ffffff;text-align:center;padding-top:5px;">' +
      '{{currentDate}}' +
      '</h3>' +
    '</ion-header-bar>',
    compile: function(element, attr) {
      var input = element.find('input');
      angular.forEach({
        'name': attr.name,
        'type': attr.type,
        'placeholder': attr.placeholder,
        'ng-value': attr.ngValue,
        'ng-model': attr.ngModel,
        'required':attr.required,
        'ng-required':attr.ngRequired,
        'ng-minlength':attr.ngMinlength,
        'ng-maxlength':attr.ngMaxlength,
        'ng-pattern':attr.ngPattern,
        'ng-change':attr.ngChange,
        'ng-trim':attr.trim,
        'ng-blur':attr.ngBlur,
        'ng-focus':attr.ngFocus,
      }, function(value, name) {
        if (angular.isDefined(value)) {
          input.attr(name, value);
        }
      });
      var cleanUp = function() {
        ionic.off('$destroy', cleanUp, element[0]);
      };
      ionic.on('$destroy', cleanUp, element[0]);
    }
  };
})

.directive("scroll", function ($rootScope) {
  return function(scope, element) {
    element.bind("scroll", function(el) {
      if (el.detail.scrollTop >= 270) {
        $rootScope.attachDate = true;
      } else {
        $rootScope.attachDate = false;
      }
      $rootScope.$apply();
    });
  };
})

.directive('dotLess', function() {
  return {
    link: function (scope, element) {
      element.bind('keydown', function() {
        var allowKeyCode = [8, 9].concat(_.range(46, 58));
        var keyCode = event.keyCode;
        var input = element[0].children[1];
        var inputValueLength = input.value && input.value.length;

        if (inputValueLength === 11) {
          input.value = input.value.slice(0, 10);
        }
        if (event.shiftKey ||
          _.indexOf(allowKeyCode, keyCode) === -1) {
          event.preventDefault();
        }
      });
    }
  };
});


