/*****************************************************************************/
/* Services:  */
/*****************************************************************************/

angular.module('maat.services', [])

.service('credentialsService', function($http, API) {
  this.cleanUsername = function (val) {
    function repeat (value, num) {
      return new Array(num + 1).join(value);
    }
    return repeat(0, 11 - val.toString().length) + val;
  };
  this.login = function(loginData) {
    var req = {
      method: 'POST',
      url: API.url + '/login',
      params: {
        username: this.cleanUsername(loginData.CPF),
        password: loginData.password
      }
    };
    return $http(req);
  };
  this.logout = function() {
    var req = {
      method: 'GET',
      url: API.url + '/logout'
    };
    return $http(req);
  };
  this.changePassword = function(passwordData) {
    var req = {
      method: 'POST',
      url: API.url + '/alterarsenha',
      params: {
        senhaatual: passwordData.currentpassword,
        senhanova: passwordData.renewpassword
      }
    };
    return $http(req);
  };
})

.service('requestService', function($http, API) {
  this.empresas = function() {
    var req = {
      method: 'GET',
      url: API.url + '/empresas'
    };
    return $http(req);
  };
  this.periodo = function(data) {
    var req = {
      method: 'GET',
      url: API.url + '/periodo',
      params: {
        inicio: data.beginDate,
        fim: data.endDate,
        idempresa: data.idEmpresa
      }
    };
    return $http(req);
  };
  this.filiais = function(data) {
    var req = {
      method: 'GET',
      url: API.url + '/filiais',
      params: {
        data: data.date,
        idempresa: data.idEmpresa
      }
    };
    return $http(req);
  };
})

.service('fix', function() {
  this.numberPlaceholder = function() {
    (function(){
      var elms = document.querySelectorAll("input");
      var i = elms.length;
      while(i--) {
        var el = elms[i];
        if (el.type === "number") {
          el.type = "text";
          el.onfocus = function(){this.type = "number";};
          el.onblur = function(){this.type = "text";};
        }
      }
    })();
  };
})

.service('calendar', function($timeout, requestService) {
  this.build = function($scope, $stateParams) {
    var self = this;
    var fillUpCalendar = function($scope) {
      if (!$scope.readyToRedraw) {return false;}
      self.fillUp($scope);
      return true;
    };
    var picker = new Pikaday({
      field: document.getElementById('datepicker'),
      firstDay: 1,
      bound: false,
      container: document.getElementById('container'),
      i18n: {
        previousMonth : 'Mês anterior',
        nextMonth     : 'Próximo mês',
        months        : ['Janeiro','Fevereiro','Março','Abril','Maio','Junho',
        'Julho','Agosto','Setembro','Outubro','Novembro','Dezembro'],
        weekdays      : ['Domingo','Segunda','Terça','Quarta','Quinta',
        'Sexta','Sábado'],
        weekdaysShort : ['Dom','Seg','Ter','Qua','Qui','Sex','Sab']
      },
      onSelect: function () {
        $scope.$parent.loadData('filiais', {
          idEmpresa: $stateParams.idEmpresa,
          date: this.getMoment().format('YYYY-MM-DD')
        });
        $scope.currentDate = this.getMoment().format('DD/MM/YYYY');
        return true;
      },
      onChange: function() {
        self.cleanUp();
        self.setPeriodoData($scope, $stateParams);
        fillUpCalendar($scope);
      },
      onDraw: function () {
        fillUpCalendar($scope);
      }
    });
    return picker;
  };
  this.setPeriodoData = function($scope, $stateParams) {
    var self = this;
    var currentMoment = $scope.picker.getMoment();
    var periodoData = {
      beginDate: currentMoment.startOf('month').format('YYYY-MM-DD'),
      endDate: currentMoment.endOf('month').format('YYYY-MM-DD'),
      idEmpresa: $stateParams.idEmpresa
    };
    $scope.readyToRedraw = false;
    requestService.periodo(periodoData)
    .success(function(data) {
      console.log('data retrieve: ', data);
      $timeout(function() {
        $scope.periodo = data.periodo;
        self.fillUp($scope);
        $scope.readyToRedraw = true;
      }, 500);
    })
    .error(function(data, status) {
      if (status !== 200) {
        console.log('Error filling up grades');
      }
    });
  };
  this.cleanUp = function() {
    _.each(document.querySelectorAll('[data-pika-day]'), function(el) {
      el.style['border-bottom'] = "none";
    });
  };
  this.fillUp = function($scope) {
    this.cleanUp();
    _.each($scope.periodo, function(day) {
      var date = moment(day.data, 'YYYY-MM-DD').date();
      var el = document.querySelectorAll('[data-pika-day="'+date+'"]')[0];
      if (el) {
        switch (day.nota) {
          case 0:
              el.style['border-bottom'] = "2px solid #3B659A";
            break;
          case 1:
              el.style['border-bottom'] = "2px solid #26BD40";
            break;
          case -1:
              el.style['border-bottom'] = "2px solid #F74032";
            break;
        }
      }
    });
    $timeout(function() {
      $scope.$parent.enableSetMonth();
      $scope.isActionable = true;
    }, 100);
  };
  this.setPrevMonthDay = function($scope) {
    var firstDayPrevMonth = $scope.picker
      .getMoment()
      .subtract(1, 'month')
      .format('YYYY-MM') + '-02';

    $scope.picker.setDate(firstDayPrevMonth);
    return true;
  };
  this.setNextMonthDay = function($scope) {
    var firstDayNextMonth = $scope.picker
      .getMoment()
      .add(1, 'month')
      .format('YYYY-MM') + '-02';

    $scope.picker.setDate(firstDayNextMonth);
    return true;
  };
});